@@ -6,7 +6,8 @@ existing database.
 """
 
 from checklists import get_data_path
-from checklists.models import SpeciesGroup
+from checklists.models import SpeciesGroup, set_current_user, \
+    clear_current_user
 
 from utils import get_data, make_inner_join, get_names, create_objects
 
@@ -24,4 +25,7 @@ def run(*args):
         initial = get_data(data_dir, 'initial.csv')
 
     table = reduce(join_on_family, get_names(data_dir), initial)
+    set_current_user('load_species_groups')
     create_objects(SpeciesGroup, table)
+    clear_current_user()
+
